@@ -112,7 +112,8 @@ CREATE TABLE PART_PRIVS
     PART_ID bigint NULL,
     PRINCIPAL_NAME nvarchar(128) NULL,
     PRINCIPAL_TYPE nvarchar(128) NULL,
-    PART_PRIV nvarchar(128) NULL
+    PART_PRIV nvarchar(128) NULL,
+    AUTHORIZER nvarchar(128) NULL
 );
 
 ALTER TABLE PART_PRIVS ADD CONSTRAINT PART_PRIVS_PK PRIMARY KEY (PART_GRANT_ID);
@@ -177,7 +178,8 @@ CREATE TABLE GLOBAL_PRIVS
     GRANTOR_TYPE nvarchar(128) NULL,
     PRINCIPAL_NAME nvarchar(128) NULL,
     PRINCIPAL_TYPE nvarchar(128) NULL,
-    USER_PRIV nvarchar(128) NULL
+    USER_PRIV nvarchar(128) NULL,
+    AUTHORIZER nvarchar(128) NULL
 );
 
 ALTER TABLE GLOBAL_PRIVS ADD CONSTRAINT GLOBAL_PRIVS_PK PRIMARY KEY (USER_GRANT_ID);
@@ -194,7 +196,8 @@ CREATE TABLE PART_COL_PRIVS
     PART_ID bigint NULL,
     PRINCIPAL_NAME nvarchar(128) NULL,
     PRINCIPAL_TYPE nvarchar(128) NULL,
-    PART_COL_PRIV nvarchar(128) NULL
+    PART_COL_PRIV nvarchar(128) NULL,
+    AUTHORIZER nvarchar(128) NULL
 );
 
 ALTER TABLE PART_COL_PRIVS ADD CONSTRAINT PART_COL_PRIVS_PK PRIMARY KEY (PART_COLUMN_GRANT_ID);
@@ -210,7 +213,8 @@ CREATE TABLE DB_PRIVS
     GRANTOR_TYPE nvarchar(128) NULL,
     PRINCIPAL_NAME nvarchar(128) NULL,
     PRINCIPAL_TYPE nvarchar(128) NULL,
-    DB_PRIV nvarchar(128) NULL
+    DB_PRIV nvarchar(128) NULL,
+    AUTHORIZER nvarchar(128) NULL
 );
 
 ALTER TABLE DB_PRIVS ADD CONSTRAINT DB_PRIVS_PK PRIMARY KEY (DB_GRANT_ID);
@@ -242,6 +246,7 @@ CREATE TABLE TAB_COL_STATS
 );
 
 ALTER TABLE TAB_COL_STATS ADD CONSTRAINT TAB_COL_STATS_PK PRIMARY KEY (CS_ID);
+CREATE INDEX TAB_COL_STATS_IDX ON TAB_COL_STATS (CAT_NAME, DB_NAME, TABLE_NAME, COLUMN_NAME);
 
 -- Table TYPES for classes [org.apache.hadoop.hive.metastore.model.MType]
 CREATE TABLE TYPES
@@ -265,7 +270,8 @@ CREATE TABLE TBL_PRIVS
     PRINCIPAL_NAME nvarchar(128) NULL,
     PRINCIPAL_TYPE nvarchar(128) NULL,
     TBL_PRIV nvarchar(128) NULL,
-    TBL_ID bigint NULL
+    TBL_ID bigint NULL,
+    AUTHORIZER nvarchar(128) NULL
 );
 
 ALTER TABLE TBL_PRIVS ADD CONSTRAINT TBL_PRIVS_PK PRIMARY KEY (TBL_GRANT_ID);
@@ -279,7 +285,8 @@ CREATE TABLE DBS
     "NAME" nvarchar(128) NULL,
     OWNER_NAME nvarchar(128) NULL,
     OWNER_TYPE nvarchar(10) NULL,
-    CTLG_NAME nvarchar(256)
+    CTLG_NAME nvarchar(256) DEFAULT 'hive',
+    CREATE_TIME INT
 );
 
 ALTER TABLE DBS ADD CONSTRAINT DBS_PK PRIMARY KEY (DB_ID);
@@ -296,7 +303,8 @@ CREATE TABLE TBL_COL_PRIVS
     PRINCIPAL_NAME nvarchar(128) NULL,
     PRINCIPAL_TYPE nvarchar(128) NULL,
     TBL_COL_PRIV nvarchar(128) NULL,
-    TBL_ID bigint NULL
+    TBL_ID bigint NULL,
+    AUTHORIZER nvarchar(128) NULL
 );
 
 ALTER TABLE TBL_COL_PRIVS ADD CONSTRAINT TBL_COL_PRIVS_PK PRIMARY KEY (TBL_COLUMN_GRANT_ID);
@@ -381,7 +389,8 @@ CREATE TABLE MV_CREATION_METADATA
     CAT_NAME nvarchar(256) NOT NULL,
     DB_NAME nvarchar(128) NOT NULL,
     TBL_NAME nvarchar(256) NOT NULL,
-    TXN_LIST text NULL
+    TXN_LIST text NULL,
+    MATERIALIZATION_TIME bigint NOT NULL
 );
 
 ALTER TABLE MV_CREATION_METADATA ADD CONSTRAINT MV_CREATION_METADATA_PK PRIMARY KEY (MV_CREATION_METADATA_ID);
@@ -590,7 +599,7 @@ CREATE TABLE PARTITION_PARAMS
 (
     PART_ID bigint NOT NULL,
     PARAM_KEY nvarchar(256) NOT NULL,
-    PARAM_VALUE nvarchar(4000) NULL
+    PARAM_VALUE varchar(max) NULL
 );
 
 ALTER TABLE PARTITION_PARAMS ADD CONSTRAINT PARTITION_PARAMS_PK PRIMARY KEY (PART_ID,PARAM_KEY);
@@ -689,9 +698,13 @@ CREATE TABLE CTLGS (
       CTLG_ID bigint primary key,
       "NAME" nvarchar(256),
       "DESC" nvarchar(4000),
-      LOCATION_URI nvarchar(4000) not null
+      LOCATION_URI nvarchar(4000) not null,
+      CREATE_TIME INT
 );
 
+-- Insert a default value.  The location is TBD.  Hive will fix this when it starts
+INSERT INTO CTLGS VALUES (1, 'hive', 'Default catalog for Hive', 'TBD', NULL);
+
 CREATE UNIQUE INDEX UNIQUE_CTLG ON CTLGS ("NAME");
 
 -- Constraints for table MASTER_KEYS for class(es) [org.apache.hadoop.hive.metastore.model.MMasterKey]
@@ -721,7 +734,7 @@ CREATE INDEX PART_COL_STATS_N49 ON PART_COL_STATS (PART_ID);
 -- Constraints for table PART_PRIVS for class(es) [org.apache.hadoop.hive.metastore.model.MPartitionPrivilege]
 ALTER TABLE PART_PRIVS ADD CONSTRAINT PART_PRIVS_FK1 FOREIGN KEY (PART_ID) REFERENCES PARTITIONS (PART_ID) ;
 
-CREATE INDEX PARTPRIVILEGEINDEX ON PART_PRIVS (PART_ID,PRINCIPAL_NAME,PRINCIPAL_TYPE,PART_PRIV,GRANTOR,GRANTOR_TYPE);
+CREATE INDEX PARTPRIVILEGEINDEX ON PART_PRIVS (AUTHORIZER,PART_ID,PRINCIPAL_NAME,PRINCIPAL_TYPE,PART_PRIV,GRANTOR,GRANTOR_TYPE);
 
 CREATE INDEX PART_PRIVS_N49 ON PART_PRIVS (PART_ID);
 
@@ -749,7 +762,7 @@ CREATE UNIQUE INDEX UNIQUEPARTITION ON PARTITIONS (PART_NAME,TBL_ID);
 -- Constraints for table VERSION for class(es) [org.apache.hadoop.hive.metastore.model.MVersionTable]
 
 -- Constraints for table GLOBAL_PRIVS for class(es) [org.apache.hadoop.hive.metastore.model.MGlobalPrivilege]
-CREATE UNIQUE INDEX GLOBALPRIVILEGEINDEX ON GLOBAL_PRIVS (PRINCIPAL_NAME,PRINCIPAL_TYPE,USER_PRIV,GRANTOR,GRANTOR_TYPE);
+CREATE UNIQUE INDEX GLOBALPRIVILEGEINDEX ON GLOBAL_PRIVS (AUTHORIZER,PRINCIPAL_NAME,PRINCIPAL_TYPE,USER_PRIV,GRANTOR,GRANTOR_TYPE);
 
 
 -- Constraints for table PART_COL_PRIVS for class(es) [org.apache.hadoop.hive.metastore.model.MPartitionColumnPrivilege]
@@ -757,13 +770,13 @@ ALTER TABLE PART_COL_PRIVS ADD CONSTRAINT PART_COL_PRIVS_FK1 FOREIGN KEY (PART_I
 
 CREATE INDEX PART_COL_PRIVS_N49 ON PART_COL_PRIVS (PART_ID);
 
-CREATE INDEX PARTITIONCOLUMNPRIVILEGEINDEX ON PART_COL_PRIVS (PART_ID,"COLUMN_NAME",PRINCIPAL_NAME,PRINCIPAL_TYPE,PART_COL_PRIV,GRANTOR,GRANTOR_TYPE);
+CREATE INDEX PARTITIONCOLUMNPRIVILEGEINDEX ON PART_COL_PRIVS (AUTHORIZER,PART_ID,"COLUMN_NAME",PRINCIPAL_NAME,PRINCIPAL_TYPE,PART_COL_PRIV,GRANTOR,GRANTOR_TYPE);
 
 
 -- Constraints for table DB_PRIVS for class(es) [org.apache.hadoop.hive.metastore.model.MDBPrivilege]
 ALTER TABLE DB_PRIVS ADD CONSTRAINT DB_PRIVS_FK1 FOREIGN KEY (DB_ID) REFERENCES DBS (DB_ID) ;
 
-CREATE UNIQUE INDEX DBPRIVILEGEINDEX ON DB_PRIVS (DB_ID,PRINCIPAL_NAME,PRINCIPAL_TYPE,DB_PRIV,GRANTOR,GRANTOR_TYPE);
+CREATE UNIQUE INDEX DBPRIVILEGEINDEX ON DB_PRIVS (AUTHORIZER,DB_ID,PRINCIPAL_NAME,PRINCIPAL_TYPE,DB_PRIV,GRANTOR,GRANTOR_TYPE);
 
 CREATE INDEX DB_PRIVS_N49 ON DB_PRIVS (DB_ID);
 
@@ -783,7 +796,7 @@ ALTER TABLE TBL_PRIVS ADD CONSTRAINT TBL_PRIVS_FK1 FOREIGN KEY (TBL_ID) REFERENC
 
 CREATE INDEX TBL_PRIVS_N49 ON TBL_PRIVS (TBL_ID);
 
-CREATE INDEX TABLEPRIVILEGEINDEX ON TBL_PRIVS (TBL_ID,PRINCIPAL_NAME,PRINCIPAL_TYPE,TBL_PRIV,GRANTOR,GRANTOR_TYPE);
+CREATE INDEX TABLEPRIVILEGEINDEX ON TBL_PRIVS (AUTHORIZER,TBL_ID,PRINCIPAL_NAME,PRINCIPAL_TYPE,TBL_PRIV,GRANTOR,GRANTOR_TYPE);
 
 
 -- Constraints for table DBS for class(es) [org.apache.hadoop.hive.metastore.model.MDatabase]
@@ -793,7 +806,7 @@ CREATE UNIQUE INDEX UNIQUEDATABASE ON DBS ("NAME", "CTLG_NAME");
 -- Constraints for table TBL_COL_PRIVS for class(es) [org.apache.hadoop.hive.metastore.model.MTableColumnPrivilege]
 ALTER TABLE TBL_COL_PRIVS ADD CONSTRAINT TBL_COL_PRIVS_FK1 FOREIGN KEY (TBL_ID) REFERENCES TBLS (TBL_ID) ;
 
-CREATE INDEX TABLECOLUMNPRIVILEGEINDEX ON TBL_COL_PRIVS (TBL_ID,"COLUMN_NAME",PRINCIPAL_NAME,PRINCIPAL_TYPE,TBL_COL_PRIV,GRANTOR,GRANTOR_TYPE);
+CREATE INDEX TABLECOLUMNPRIVILEGEINDEX ON TBL_COL_PRIVS (AUTHORIZER,TBL_ID,"COLUMN_NAME",PRINCIPAL_NAME,PRINCIPAL_TYPE,TBL_COL_PRIV,GRANTOR,GRANTOR_TYPE);
 
 CREATE INDEX TBL_COL_PRIVS_N49 ON TBL_COL_PRIVS (TBL_ID);
 
@@ -1027,7 +1040,8 @@ CREATE TABLE COMPLETED_TXN_COMPONENTS(
 	CTC_TABLE nvarchar(128) NULL,
 	CTC_PARTITION nvarchar(767) NULL,
     CTC_TIMESTAMP datetime2 DEFAULT CURRENT_TIMESTAMP NOT NULL,
-    CTC_WRITEID bigint
+    CTC_WRITEID bigint,
+    CTC_UPDATE_DELETE char(1) NOT NULL
 );
 
 CREATE INDEX COMPLETED_TXN_COMPONENTS_IDX ON COMPLETED_TXN_COMPONENTS (CTC_DATABASE, CTC_TABLE, CTC_PARTITION);
@@ -1084,6 +1098,7 @@ CREATE TABLE TXNS(
     TXN_AGENT_INFO nvarchar(128) NULL,
     TXN_META_INFO nvarchar(128) NULL,
     TXN_HEARTBEAT_COUNT int NULL,
+    TXN_TYPE int NULL,
 PRIMARY KEY CLUSTERED
 (
 	TXN_ID ASC
@@ -1183,6 +1198,17 @@ PRIMARY KEY CLUSTERED
 
 CREATE INDEX MIN_HISTORY_LEVEL_IDX ON MIN_HISTORY_LEVEL (MHL_MIN_OPEN_TXNID);
 
+CREATE TABLE MATERIALIZATION_REBUILD_LOCKS (
+  MRL_TXN_ID bigint NOT NULL,
+  MRL_DB_NAME nvarchar(128) NOT NULL,
+  MRL_TBL_NAME nvarchar(256) NOT NULL,
+  MRL_LAST_HEARTBEAT bigint NOT NULL,
+PRIMARY KEY CLUSTERED
+(
+    MRL_TXN_ID ASC
+)
+);
+
 CREATE TABLE "I_SCHEMA" (
   "SCHEMA_ID" bigint primary key,
   "SCHEMA_TYPE" int not null,
@@ -1240,7 +1266,24 @@ CREATE TABLE RUNTIME_STATS (
 
 CREATE INDEX IDX_RUNTIME_STATS_CREATE_TIME ON RUNTIME_STATS(CREATE_TIME);
 
+CREATE TABLE TXN_WRITE_NOTIFICATION_LOG (
+  WNL_ID bigint NOT NULL,
+  WNL_TXNID bigint NOT NULL,
+  WNL_WRITEID bigint NOT NULL,
+  WNL_DATABASE nvarchar(128) NOT NULL,
+  WNL_TABLE nvarchar(128) NOT NULL,
+  WNL_PARTITION nvarchar(767) NOT NULL,
+  WNL_TABLE_OBJ text NOT NULL,
+  WNL_PARTITION_OBJ text,
+  WNL_FILES text,
+  WNL_EVENT_TIME int NOT NULL
+);
+
+ALTER TABLE TXN_WRITE_NOTIFICATION_LOG ADD CONSTRAINT TXN_WRITE_NOTIFICATION_LOG_PK PRIMARY KEY (WNL_TXNID, WNL_DATABASE, WNL_TABLE, WNL_PARTITION);
+
+INSERT INTO SEQUENCE_TABLE (SEQUENCE_NAME, NEXT_VAL) VALUES ('org.apache.hadoop.hive.metastore.model.MTxnWriteNotificationLog', 1);
+
 -- -----------------------------------------------------------------
 -- Record schema version. Should be the last step in the init script
 -- -----------------------------------------------------------------
-INSERT INTO VERSION (VER_ID, SCHEMA_VERSION, VERSION_COMMENT) VALUES (1, '3.0.0', 'Hive release version 3.0.0');
+INSERT INTO VERSION (VER_ID, SCHEMA_VERSION, VERSION_COMMENT) VALUES (1, '3.2.0', 'Hive release version 3.2.0');
