@@ -63,9 +63,13 @@ CREATE TABLE "CTLGS" (
     "CTLG_ID" BIGINT PRIMARY KEY,
     "NAME" VARCHAR(256) UNIQUE,
     "DESC" VARCHAR(4000),
-    "LOCATION_URI" VARCHAR(4000) NOT NULL
+    "LOCATION_URI" VARCHAR(4000) NOT NULL,
+    "CREATE_TIME" bigint
 );
 
+-- Insert a default value.  The location is TBD.  Hive will fix this when it starts
+INSERT INTO "CTLGS" VALUES (1, 'hive', 'Default catalog for Hive', 'TBD', NULL);
+
 --
 -- Name: DBS; Type: TABLE; Schema: public; Owner: hiveuser; Tablespace:
 --
@@ -77,7 +81,8 @@ CREATE TABLE "DBS" (
     "NAME" character varying(128) DEFAULT NULL::character varying,
     "OWNER_NAME" character varying(128) DEFAULT NULL::character varying,
     "OWNER_TYPE" character varying(10) DEFAULT NULL::character varying,
-    "CTLG_NAME" varchar(256)
+    "CTLG_NAME" varchar(256) DEFAULT 'hive' NOT NULL,
+    "CREATE_TIME" bigint
 );
 
 
@@ -94,7 +99,8 @@ CREATE TABLE "DB_PRIVS" (
     "GRANTOR_TYPE" character varying(128) DEFAULT NULL::character varying,
     "PRINCIPAL_NAME" character varying(128) DEFAULT NULL::character varying,
     "PRINCIPAL_TYPE" character varying(128) DEFAULT NULL::character varying,
-    "DB_PRIV" character varying(128) DEFAULT NULL::character varying
+    "DB_PRIV" character varying(128) DEFAULT NULL::character varying,
+    "AUTHORIZER" character varying(128) DEFAULT NULL::character varying
 );
 
 
@@ -110,7 +116,8 @@ CREATE TABLE "GLOBAL_PRIVS" (
     "GRANTOR_TYPE" character varying(128) DEFAULT NULL::character varying,
     "PRINCIPAL_NAME" character varying(128) DEFAULT NULL::character varying,
     "PRINCIPAL_TYPE" character varying(128) DEFAULT NULL::character varying,
-    "USER_PRIV" character varying(128) DEFAULT NULL::character varying
+    "USER_PRIV" character varying(128) DEFAULT NULL::character varying,
+    "AUTHORIZER" character varying(128) DEFAULT NULL::character varying
 );
 
 
@@ -216,7 +223,7 @@ CREATE TABLE "PARTITION_KEY_VALS" (
 CREATE TABLE "PARTITION_PARAMS" (
     "PART_ID" bigint NOT NULL,
     "PARAM_KEY" character varying(256) NOT NULL,
-    "PARAM_VALUE" character varying(4000) DEFAULT NULL::character varying
+    "PARAM_VALUE" text DEFAULT NULL
 );
 
 
@@ -234,7 +241,8 @@ CREATE TABLE "PART_COL_PRIVS" (
     "PART_ID" bigint,
     "PRINCIPAL_NAME" character varying(128) DEFAULT NULL::character varying,
     "PRINCIPAL_TYPE" character varying(128) DEFAULT NULL::character varying,
-    "PART_COL_PRIV" character varying(128) DEFAULT NULL::character varying
+    "PART_COL_PRIV" character varying(128) DEFAULT NULL::character varying,
+    "AUTHORIZER" character varying(128) DEFAULT NULL::character varying
 );
 
 
@@ -251,7 +259,8 @@ CREATE TABLE "PART_PRIVS" (
     "PART_ID" bigint,
     "PRINCIPAL_NAME" character varying(128) DEFAULT NULL::character varying,
     "PRINCIPAL_TYPE" character varying(128) DEFAULT NULL::character varying,
-    "PART_PRIV" character varying(128) DEFAULT NULL::character varying
+    "PART_PRIV" character varying(128) DEFAULT NULL::character varying,
+    "AUTHORIZER" character varying(128) DEFAULT NULL::character varying
 );
 
 
@@ -400,7 +409,8 @@ CREATE TABLE "MV_CREATION_METADATA" (
     "CAT_NAME" character varying(256) NOT NULL,
     "DB_NAME" character varying(128) NOT NULL,
     "TBL_NAME" character varying(256) NOT NULL,
-    "TXN_LIST" text
+    "TXN_LIST" text,
+    "MATERIALIZATION_TIME" bigint NOT NULL
 );
 
 --
@@ -426,7 +436,8 @@ CREATE TABLE "TBL_COL_PRIVS" (
     "PRINCIPAL_NAME" character varying(128) DEFAULT NULL::character varying,
     "PRINCIPAL_TYPE" character varying(128) DEFAULT NULL::character varying,
     "TBL_COL_PRIV" character varying(128) DEFAULT NULL::character varying,
-    "TBL_ID" bigint
+    "TBL_ID" bigint,
+    "AUTHORIZER" character varying(128) DEFAULT NULL::character varying
 );
 
 
@@ -443,7 +454,8 @@ CREATE TABLE "TBL_PRIVS" (
     "PRINCIPAL_NAME" character varying(128) DEFAULT NULL::character varying,
     "PRINCIPAL_TYPE" character varying(128) DEFAULT NULL::character varying,
     "TBL_PRIV" character varying(128) DEFAULT NULL::character varying,
-    "TBL_ID" bigint
+    "TBL_ID" bigint,
+    "AUTHORIZER" character varying(128) DEFAULT NULL::character varying
 );
 
 
@@ -735,7 +747,7 @@ ALTER TABLE ONLY "DATABASE_PARAMS"
 --
 
 ALTER TABLE ONLY "DB_PRIVS"
-    ADD CONSTRAINT "DBPRIVILEGEINDEX" UNIQUE ("DB_ID", "PRINCIPAL_NAME", "PRINCIPAL_TYPE", "DB_PRIV", "GRANTOR", "GRANTOR_TYPE");
+    ADD CONSTRAINT "DBPRIVILEGEINDEX" UNIQUE ("AUTHORIZER", "DB_ID", "PRINCIPAL_NAME", "PRINCIPAL_TYPE", "DB_PRIV", "GRANTOR", "GRANTOR_TYPE");
 
 
 --
@@ -759,7 +771,7 @@ ALTER TABLE ONLY "DB_PRIVS"
 --
 
 ALTER TABLE ONLY "GLOBAL_PRIVS"
-    ADD CONSTRAINT "GLOBALPRIVILEGEINDEX" UNIQUE ("PRINCIPAL_NAME", "PRINCIPAL_TYPE", "USER_PRIV", "GRANTOR", "GRANTOR_TYPE");
+    ADD CONSTRAINT "GLOBALPRIVILEGEINDEX" UNIQUE ("AUTHORIZER", "PRINCIPAL_NAME", "PRINCIPAL_TYPE", "USER_PRIV", "GRANTOR", "GRANTOR_TYPE");
 
 
 --
@@ -1024,7 +1036,7 @@ ALTER TABLE ONLY "TBLS"
 --
 
 ALTER TABLE ONLY "DBS"
-    ADD CONSTRAINT "UNIQUE_DATABASE" UNIQUE ("NAME");
+    ADD CONSTRAINT "UNIQUE_DATABASE" UNIQUE ("NAME", "CTLG_NAME");
 
 
 --
@@ -1127,7 +1139,7 @@ CREATE INDEX "INDEX_PARAMS_N49" ON "INDEX_PARAMS" USING btree ("INDEX_ID");
 -- Name: PARTITIONCOLUMNPRIVILEGEINDEX; Type: INDEX; Schema: public; Owner: hiveuser; Tablespace:
 --
 
-CREATE INDEX "PARTITIONCOLUMNPRIVILEGEINDEX" ON "PART_COL_PRIVS" USING btree ("PART_ID", "COLUMN_NAME", "PRINCIPAL_NAME", "PRINCIPAL_TYPE", "PART_COL_PRIV", "GRANTOR", "GRANTOR_TYPE");
+CREATE INDEX "PARTITIONCOLUMNPRIVILEGEINDEX" ON "PART_COL_PRIVS" USING btree ("AUTHORIZER", "PART_ID", "COLUMN_NAME", "PRINCIPAL_NAME", "PRINCIPAL_TYPE", "PART_COL_PRIV", "GRANTOR", "GRANTOR_TYPE");
 
 
 --
@@ -1176,7 +1188,7 @@ CREATE INDEX "PARTITION_PARAMS_N49" ON "PARTITION_PARAMS" USING btree ("PART_ID"
 -- Name: PARTPRIVILEGEINDEX; Type: INDEX; Schema: public; Owner: hiveuser; Tablespace:
 --
 
-CREATE INDEX "PARTPRIVILEGEINDEX" ON "PART_PRIVS" USING btree ("PART_ID", "PRINCIPAL_NAME", "PRINCIPAL_TYPE", "PART_PRIV", "GRANTOR", "GRANTOR_TYPE");
+CREATE INDEX "PARTPRIVILEGEINDEX" ON "PART_PRIVS" USING btree ("AUTHORIZER", "PART_ID", "PRINCIPAL_NAME", "PRINCIPAL_TYPE", "PART_PRIV", "GRANTOR", "GRANTOR_TYPE");
 
 
 --
@@ -1239,14 +1251,14 @@ CREATE INDEX "SORT_COLS_N49" ON "SORT_COLS" USING btree ("SD_ID");
 -- Name: TABLECOLUMNPRIVILEGEINDEX; Type: INDEX; Schema: public; Owner: hiveuser; Tablespace:
 --
 
-CREATE INDEX "TABLECOLUMNPRIVILEGEINDEX" ON "TBL_COL_PRIVS" USING btree ("TBL_ID", "COLUMN_NAME", "PRINCIPAL_NAME", "PRINCIPAL_TYPE", "TBL_COL_PRIV", "GRANTOR", "GRANTOR_TYPE");
+CREATE INDEX "TABLECOLUMNPRIVILEGEINDEX" ON "TBL_COL_PRIVS" USING btree ("AUTHORIZER", "TBL_ID", "COLUMN_NAME", "PRINCIPAL_NAME", "PRINCIPAL_TYPE", "TBL_COL_PRIV", "GRANTOR", "GRANTOR_TYPE");
 
 
 --
 -- Name: TABLEPRIVILEGEINDEX; Type: INDEX; Schema: public; Owner: hiveuser; Tablespace:
 --
 
-CREATE INDEX "TABLEPRIVILEGEINDEX" ON "TBL_PRIVS" USING btree ("TBL_ID", "PRINCIPAL_NAME", "PRINCIPAL_TYPE", "TBL_PRIV", "GRANTOR", "GRANTOR_TYPE");
+CREATE INDEX "TABLEPRIVILEGEINDEX" ON "TBL_PRIVS" USING btree ("AUTHORIZER", "TBL_ID", "PRINCIPAL_NAME", "PRINCIPAL_TYPE", "TBL_PRIV", "GRANTOR", "GRANTOR_TYPE");
 
 
 --
@@ -1276,6 +1288,11 @@ CREATE INDEX "TBLS_N50" ON "TBLS" USING btree ("SD_ID");
 
 CREATE INDEX "TBL_COL_PRIVS_N49" ON "TBL_COL_PRIVS" USING btree ("TBL_ID");
 
+--
+-- Name: TAB_COL_STATS_IDX; Type: INDEX; Schema: public; Owner: hiveuser; Tablespace:
+--
+
+CREATE INDEX "TAB_COL_STATS_IDX" ON "TAB_COL_STATS" USING btree ("CAT_NAME", "DB_NAME","TABLE_NAME","COLUMN_NAME");
 
 --
 -- Name: TBL_PRIVS_N49; Type: INDEX; Schema: public; Owner: hiveuser; Tablespace:
@@ -1641,7 +1658,8 @@ CREATE TABLE TXNS (
   TXN_HOST varchar(128) NOT NULL,
   TXN_AGENT_INFO varchar(128),
   TXN_META_INFO varchar(128),
-  TXN_HEARTBEAT_COUNT integer
+  TXN_HEARTBEAT_COUNT integer,
+  TXN_TYPE integer
 );
 
 CREATE TABLE TXN_COMPONENTS (
@@ -1661,7 +1679,8 @@ CREATE TABLE COMPLETED_TXN_COMPONENTS (
   CTC_TABLE varchar(256),
   CTC_PARTITION varchar(767),
   CTC_TIMESTAMP timestamp DEFAULT CURRENT_TIMESTAMP NOT NULL,
-  CTC_WRITEID bigint
+  CTC_WRITEID bigint,
+  CTC_UPDATE_DELETE char(1) NOT NULL
 );
 
 CREATE INDEX COMPLETED_TXN_COMPONENTS_INDEX ON COMPLETED_TXN_COMPONENTS USING btree (CTC_DATABASE, CTC_TABLE, CTC_PARTITION);
@@ -1778,6 +1797,14 @@ CREATE TABLE MIN_HISTORY_LEVEL (
 
 CREATE INDEX MIN_HISTORY_LEVEL_IDX ON MIN_HISTORY_LEVEL (MHL_MIN_OPEN_TXNID);
 
+CREATE TABLE MATERIALIZATION_REBUILD_LOCKS (
+  MRL_TXN_ID bigint NOT NULL,
+  MRL_DB_NAME varchar(128) NOT NULL,
+  MRL_TBL_NAME varchar(256) NOT NULL,
+  MRL_LAST_HEARTBEAT bigint NOT NULL,
+  PRIMARY KEY(MRL_TXN_ID)
+);
+
 CREATE TABLE "I_SCHEMA" (
   "SCHEMA_ID" bigint primary key,
   "SCHEMA_TYPE" integer not null,
@@ -1822,8 +1849,23 @@ CREATE TABLE RUNTIME_STATS (
 
 CREATE INDEX IDX_RUNTIME_STATS_CREATE_TIME ON RUNTIME_STATS(CREATE_TIME);
 
+CREATE TABLE "TXN_WRITE_NOTIFICATION_LOG" (
+  "WNL_ID" bigint NOT NULL,
+  "WNL_TXNID" bigint NOT NULL,
+  "WNL_WRITEID" bigint NOT NULL,
+  "WNL_DATABASE" varchar(128) NOT NULL,
+  "WNL_TABLE" varchar(128) NOT NULL,
+  "WNL_PARTITION" varchar(767) NOT NULL,
+  "WNL_TABLE_OBJ" text NOT NULL,
+  "WNL_PARTITION_OBJ" text,
+  "WNL_FILES" text,
+  "WNL_EVENT_TIME" integer NOT NULL,
+  PRIMARY KEY ("WNL_TXNID", "WNL_DATABASE", "WNL_TABLE", "WNL_PARTITION")
+);
+
+INSERT INTO "SEQUENCE_TABLE" ("SEQUENCE_NAME", "NEXT_VAL") VALUES ('org.apache.hadoop.hive.metastore.model.MTxnWriteNotificationLog', 1);
 
 -- -----------------------------------------------------------------
 -- Record schema version. Should be the last step in the init script
 -- -----------------------------------------------------------------
-INSERT INTO "VERSION" ("VER_ID", "SCHEMA_VERSION", "VERSION_COMMENT") VALUES (1, '3.0.0', 'Hive release version 3.0.0');
+INSERT INTO "VERSION" ("VER_ID", "SCHEMA_VERSION", "VERSION_COMMENT") VALUES (1, '3.2.0', 'Hive release version 3.2.0');
